@@ -1,4 +1,3 @@
-
 from assembly_payments.services.base import BaseService
 from assembly_payments.types import Company, CompanyRequest
 
@@ -10,7 +9,7 @@ class CompanyService(BaseService):
 
     def get(self, company_id):
         response = self._execute(CompanyService.GET, f"{self.endpoint}/{company_id}")
-        return Company(**response['companies'])
+        return Company(**response["companies"])
 
     def list(self, *args, **kwargs):
         response = self._execute(CompanyService.GET, self.endpoint)
@@ -19,4 +18,13 @@ class CompanyService(BaseService):
     def create(self, **kwargs):
         data = CompanyRequest(**kwargs)
         response = self._execute(CompanyService.POST, self.endpoint, data=data.dict())
-        return Company(**response['companies'])
+        return Company(**response["companies"])
+
+    def update(self, company_id, **kwargs):
+        data = CompanyRequest(**kwargs)
+        response = self._execute(
+            CompanyService.PATCH,
+            f"{self.endpoint}/{company_id}",
+            data=data.dict(exclude_none=True),
+        )
+        return Company(**response["companies"])
