@@ -1,3 +1,4 @@
+import datetime
 from typing import Union, Optional, Any, List
 
 from pydantic.main import BaseModel
@@ -145,6 +146,7 @@ class Disbursement(BaseModel):
 
 
 class Transaction(BaseModel):
+    id: str
     description: str
     type: str
     type_method: str
@@ -161,6 +163,18 @@ class Transaction(BaseModel):
     updated_at: Optional[Union[None, str]]
 
 
+class TransactionSupplementaryData(BaseModel):
+    id: str
+    debtor_name: str
+    debtor_account: str
+    creditor_account: str
+    creditor_name: str
+    remittance_information: str
+    type: str
+    type_method: str
+    npp_details: Optional[dict]
+
+
 class ItemBase(BaseModel):
     id: str
     name: str
@@ -191,6 +205,21 @@ class Item(ItemBase):
     currency: str
 
 
+class PaginationFilters(BaseModel):
+    offset: int = None
+    limit: int = None
+
+
+class UserItemFilters(PaginationFilters):
+    pass
+
+
+class ItemFilters(PaginationFilters):
+    search: str = None
+    created_before: datetime.datetime = None
+    created_after: datetime.datetime = None
+
+
 class MakePaymentRequest(BaseModel):
     account_id: str
 
@@ -248,6 +277,10 @@ class DirectDebitAuthority(BaseModel):
     state: str
 
 
+class DirectDebitAuthorityFilters(PaginationFilters):
+    account_id: str
+
+
 class DirectDebitAuthorityRequest(BaseModel):
     amount: int
     account_id: str
@@ -359,4 +392,4 @@ class BPayAccount(BaseModel):
 
 class BPayAccountRequest(BPayDetailsBase):
     user_id: str
-    bpay_crn: int
+    bpay_crn: str
