@@ -127,6 +127,7 @@ def DisbursementFactory(**kwargs):
 
 def TransactionFactory(**kwargs):
     data = dict(
+        id=str(uuid.uuid4()),
         description=fake.word(),
         type="payment",
         type_method="credit_card",
@@ -273,8 +274,29 @@ def BPayAccountFactory(**kwargs):
             biller_code=fake.pyint(),
             biller_name=fake.word(),
             account_number="XXX123",
-            crn=fake.pyint(),
+            crn=str(fake.pyint()),
         ),
     )
     data.update(kwargs)
     return data
+
+
+def TransactionSupplementaryDataFactory(**kwargs):
+    data = dict(
+        id=str(uuid.uuid4),
+        debtor_name=fake.word(),
+        debtor_account=str(fake.numerify("######")),
+        creditor_account=str(fake.numerify("######")),
+        creditor_name=fake.word(),
+        remittance_information=str(fake.numerify("######")),
+        type="deposit",
+        type_method="npp_payin",
+        npp_details=dict(
+            pay_id=fake.email(),
+            pay_id_type="EMAIL",
+            clearing_system_transaction_id=fake.word(),
+            end_to_end_id=fake.word(),
+        )
+    )
+    data.update(kwargs)
+    return data
